@@ -33,7 +33,8 @@ Editor::Editor(QWidget *parent, const char *name)
 	setIcon(QPixmap::fromMimeSource("document.png"));
 
 	isUntitled = true;
-	fileFilters = tr("Text files (*.txt)\n"
+	fileFilters = tr("type enforcement file (*.te)\n"
+		"text files (*.txt)\n"
 		"csv files (*.csv)\n"
 		"All files (*)");
 }
