@@ -39,17 +39,27 @@
 //default constructor
 SegatexAudit2allow::SegatexAudit2allow(QWidget *parent, const char *name): QDialog(parent, name)
 {
-		setCaption(tr("audit2allow(only root can do this)"));
+		setCaption(tr("audit2allow"));
+		readfromLabel = new QLabel(tr("Read from:"), this );
+		writetoLabel = new QLabel(tr("Write to:"), this );
+		auditlogCheckBox = new QCheckBox(tr("/var/log/audit/audit.log"), this);
+		messagesCheckBox = new QCheckBox(tr("/var/log/messages"), this);
 		lastreloadCheckBox = new QCheckBox(tr("read input only after the last reload"), this);
 		referenceCheckBox = new QCheckBox(tr("generate refpolicy style output"), this);
 		verboseCheckBox = new QCheckBox(tr("explain genetated output"), this);
 		explainCheckBox = new QCheckBox(tr("fully explain genetated output"), this);
-		//targetedCheckBox->setChecked(true);
-		//strictCheckBox->setChecked(true);
+		auditlogCheckBox->setChecked(true);
+		messagesCheckBox->setChecked(true);
 		//mlsCheckBox->setChecked(true);
+		moduleNameLabel = new QLabel(tr("Module Name( alphabet and numbers only \"_\" can't be used):"), this );
+		moduleNameLineEdit = new QLineEdit( this );
+		writetoLineEdit = new QLineEdit( this );
+		moduleNameLineEdit->setText("local");
+		writetoLineEdit->setText("local.te");
 		//passwordLineEdit = new QLineEdit( this );
 		//passwordLineEdit->setEchoMode(QLineEdit::Password);
 		audit2allowButton = new QPushButton(tr("&audit2allow"), this);
+		audit2allowButton->setPaletteBackgroundColor(QColor(155, 155, 255));
 		closeButton = new QPushButton(tr("&Close"), this);
 		audit2allowButton->setDefault(true);
 
@@ -57,16 +67,22 @@ SegatexAudit2allow::SegatexAudit2allow(QWidget *parent, const char *name): QDial
 		connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 
 		QVBoxLayout *leftLayout = new QVBoxLayout;
+		leftLayout->addWidget(readfromLabel);
+		leftLayout->addWidget(auditlogCheckBox);
+		leftLayout->addWidget(messagesCheckBox);
+		leftLayout->addWidget(writetoLabel);
+		leftLayout->addWidget(writetoLineEdit);
+		leftLayout->addWidget(moduleNameLabel);
+		leftLayout->addWidget(moduleNameLineEdit);
 		leftLayout->addWidget(lastreloadCheckBox);
 		leftLayout->addWidget(referenceCheckBox);
 		leftLayout->addWidget(verboseCheckBox);
 		leftLayout->addWidget(explainCheckBox);
 
 		QVBoxLayout *rightLayout = new QVBoxLayout;
-		//rightLayout->addWidget(passwordLineEdit);
 		rightLayout->addWidget(audit2allowButton);
+		rightLayout->addStretch(2);
 		rightLayout->addWidget(closeButton);
-		rightLayout->addStretch(1);
 
 		QHBoxLayout *mainLayout = new QHBoxLayout(this);
 		mainLayout->setMargin(11);
@@ -75,10 +91,6 @@ SegatexAudit2allow::SegatexAudit2allow(QWidget *parent, const char *name): QDial
 		mainLayout->addLayout(rightLayout);
 		//needs here to be declared for window newly opened unless segmentation fault occurs
 		selinux_audit2allow_process = 0;
-		selinux_audit2allow_process_e = 0;
-		selinux_audit2allow_process_l = 0;
-		selinux_audit2allow_process_r = 0;
-		selinux_audit2allow_process_v = 0;
 }
 /*connects signal to close this window when process window's close button is clicked*/
 void SegatexAudit2allow::audit2allow_clicked()
@@ -99,48 +111,65 @@ void SegatexAudit2allow::audit2allow_clicked()
 		//-v//10
 		//-e//1
 		//no_option//0
+		moduleName_str = moduleNameLineEdit->text();
+		outputfile_str = writetoLineEdit->text();
+		moduleName_str_caption = "module " + moduleName_str + " 1.0";
 		selinux_audit2allow_process = new SegatexAudit2allowProcess(this);
 		connect(selinux_audit2allow_process, SIGNAL(audit2allow_prosess_close_button_clicked()), this, SLOT(close()));
 		connect(closeButton, SIGNAL(clicked()), selinux_audit2allow_process, SLOT(close()));
+		selinux_audit2allow_process->setCaption(tr(moduleName_str_caption));
 		selinux_audit2allow_process->show();
 		selinux_audit2allow_process->raise();
 		selinux_audit2allow_process->setActiveWindow();
 
+	if(auditlogCheckBox->isOn()){
+		if(messagesCheckBox->isOn()){
+			log_file=3;
+		}else{
+			log_file=2;
+		}
+	}else{
+		if(messagesCheckBox->isOn()){
+			log_file=1;
+		}else{
+			//maybe popupmessage is needed something like "you should check either one."
+		}
+	}
 	if(lastreloadCheckBox->isOn()){
 		if(referenceCheckBox->isOn()){
 			if(verboseCheckBox->isOn()){
 				if(explainCheckBox->isOn()){
 					//-l -R -v -e
-					selinux_audit2allow_process->audit2allow_base_process(1111);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,1111,moduleName_str);
 				}else{
 					//-l -R -v
-					selinux_audit2allow_process->audit2allow_base_process(1110);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,1110,moduleName_str);
 				}
 			}else{
 				if(explainCheckBox->isOn()){
 					//-l -R -e
-					selinux_audit2allow_process->audit2allow_base_process(1101);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,1101,moduleName_str);
 				}else{
 					//-l -R
-					selinux_audit2allow_process->audit2allow_base_process(1100);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,1100,moduleName_str);
 				}	
 			}
 		}else{
 			if(verboseCheckBox->isOn()){
 				if(explainCheckBox->isOn()){
 					//-l -v -e
-					selinux_audit2allow_process->audit2allow_base_process(1011);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,1011,moduleName_str);
 				}else{
 					//-l -v
-					selinux_audit2allow_process->audit2allow_base_process(1010);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,1010,moduleName_str);
 				}
 			}else{
 				if(explainCheckBox->isOn()){
 					//-l -e	
-					selinux_audit2allow_process->audit2allow_base_process(1001);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,1001,moduleName_str);
 				}else{
 					//-l
-					selinux_audit2allow_process->audit2allow_base_process(1000);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,1000,moduleName_str);
 				}
 			}
 		}
@@ -149,36 +178,36 @@ void SegatexAudit2allow::audit2allow_clicked()
 			if(verboseCheckBox->isOn()){
 				if(explainCheckBox->isOn()){
 					//-R -v -e
-					selinux_audit2allow_process->audit2allow_base_process(111);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,111,moduleName_str);
 				}else{
 					//-R -v
-					selinux_audit2allow_process->audit2allow_base_process(110);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,110,moduleName_str);
 				}
 			}else{
 				if(explainCheckBox->isOn()){
 					//-R -e
-					selinux_audit2allow_process->audit2allow_base_process(101);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,101,moduleName_str);
 				}else{
 					//-R
-					selinux_audit2allow_process->audit2allow_base_process(100);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,100,moduleName_str);
 				}	
 			}
 		}else{
 			if(verboseCheckBox->isOn()){
 				if(explainCheckBox->isOn()){
 					//-v -e
-					selinux_audit2allow_process->audit2allow_base_process(11);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,11,moduleName_str);
 				}else{
 					//-v
-					selinux_audit2allow_process->audit2allow_base_process(10);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,10,moduleName_str);
 				}
 			}else{
 				if(explainCheckBox->isOn()){
 					//-e
-					selinux_audit2allow_process->audit2allow_base_process(1);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,1,moduleName_str);
 				}else{
 					//no_option
-					selinux_audit2allow_process->audit2allow_base_process(0);
+					selinux_audit2allow_process->audit2allow_base_process(log_file,outputfile_str,0,moduleName_str);
 				}	
 			}
 		}
