@@ -25,6 +25,7 @@
 #include <qdialog.h>
 #include <qradiobutton.h>
 #include <qtextedit.h>
+#include <qlabel.h>
 
 
 class QLayout;
@@ -34,10 +35,6 @@ class QLineEdit;
 class QPushButton;
 class QProcess;
 class SegatexAudit2allowProcess;
-class SegatexAudit2allowProcessE;
-class SegatexAudit2allowProcessL;
-class SegatexAudit2allowProcessR;
-class SegatexAudit2allowProcessV;
 
 class SegatexAudit2allow: public QDialog
 {
@@ -45,11 +42,6 @@ class SegatexAudit2allow: public QDialog
 public:
 	SegatexAudit2allow(QWidget *parent = 0, const char *name = 0);
 	SegatexAudit2allowProcess *selinux_audit2allow_process;
-	SegatexAudit2allowProcessE *selinux_audit2allow_process_e;
-	SegatexAudit2allowProcessL *selinux_audit2allow_process_l;
-	SegatexAudit2allowProcessR *selinux_audit2allow_process_r;
-	SegatexAudit2allowProcessV *selinux_audit2allow_process_v;
-	SegatexAudit2allow *selinux_audit2allow_common_obj;
 	int j;
 public slots:
 signals:
@@ -65,15 +57,26 @@ private slots:
 private:
 	QRadioButton *auditRadioButton;
 	QRadioButton *dmesgRadioButton;
+	QCheckBox *auditlogCheckBox;
+	QCheckBox *messagesCheckBox;
 	QCheckBox *lastreloadCheckBox;
 	QCheckBox *requiresCheckBox;
 	QCheckBox *referenceCheckBox;
 	QCheckBox *verboseCheckBox;
 	QCheckBox *explainCheckBox;
-	QLineEdit *passwordLineEdit;
+	//QLineEdit *passwordLineEdit;
+	QLabel *readfromLabel;
+	QLabel *writetoLabel;
+	QLabel *moduleNameLabel;
+	QLineEdit *moduleNameLineEdit;
+	QLineEdit *writetoLineEdit;
 	QTextEdit *textEdit1;
 	QPushButton *audit2allowButton;
 	QPushButton *closeButton;
+	QString moduleName_str;
+	QString outputfile_str;
+	QString moduleName_str_caption;
+	int log_file;
 };
 
 #endif
