@@ -132,136 +132,142 @@ void SelpawAdjust::adjust_selpaw()
 			if ( file.open( IO_ReadOnly ) ) {
 				QTextStream stream( &file );
 				////////////////////////////////////////////
-				
-				QRegExp rx_interface4("\\$1"); 		
-				QRegExp rx_interface5("\\$2"); 		
-				QRegExp rx_interface6("\\$3"); 		
-				QRegExp rx_interface7("\\$4"); 		
-				QRegExp rx_aide_run("aide_run");
-				QRegExp rx_amanda_run_recover("amanda_run_recover");
-				QRegExp rx_amavis_spool_filetrans("amavis_spool_filetrans");
-				QRegExp rx_amtu_run("amtu_run");
-				QRegExp rx_apache_run_helper("apache_run_helper");
-				QRegExp rx_apt_run("apt_run");
-				QRegExp rx_auth_domtrans_login_program("auth_domtrans_login_program");
-				QRegExp rx_auth_run_pam("auth_run_pam");
-				QRegExp rx_auth_run_utempter("auth_run_utempter");
-				QRegExp rx_backup_run("backup_run");
-				QRegExp rx_bind_run_ndc("bind_run_ndc");
-				QRegExp rx_bluetooth_run_helper("bluetooth_run_helper");
-				QRegExp rx_bootloader_run("bootloader_run");
-				QRegExp rx_certwatach_run("certwatach_run");
-				QRegExp rx_clock_run("clock_run");
-				QRegExp rx_clockspeed_run_cli("clockspeed_run_cli");
-				QRegExp rx_consoletype_run("consoletype_run");
-				QRegExp rx_dcc_run_cdcc("dcc_run_cdcc");
-				QRegExp rx_dcc_run_client("dcc_run_client");
-				QRegExp rx_dcc_run_dbclean("dcc_run_dbclean");
-				QRegExp rx_ddcprobe_run("ddcprobe_run");
-				QRegExp rx_dev_filetrans("dev_filetrans");
-				QRegExp rx_dmidecode_run("dmidecode_run");
-				QRegExp rx_domain_entry_file("domain_entry_file");
-				QRegExp rx_dpkg_run("dpkg_run");
-				QRegExp rx_ethereal_run_tethereal("ethereal_run_tethereal");
-				QRegExp rx_evolution_alarm_dbus_chat("evolution_alarm_dbus_chat");
-				QRegExp rx_evolution_dbus_chat("evolution_dbus_chat");
-				QRegExp rx_files_boot_filetrans("files_boot_filetrans");
-				QRegExp rx_files_etc_filetrans("files_etc_filetrans");
-				QRegExp rx_files_etc_filetrans_etc_runtime("files_etc_filetrans_etc_runtime");
-				QRegExp rx_files_home_filetrans("files_home_filetrans");
-				QRegExp rx_files_kernel_modules_filetrans("files_kernel_modules_filetrans");
-				QRegExp rx_files_lock_filetrans("files_lock_filetrans");
-				QRegExp rx_files_manage_all_files("files_manage_all_files");
-				QRegExp rx_files_pid_filetrans("files_pid_filetrans");
-				QRegExp rx_files_read_all_dirs_except("files_read_all_dirs_except");
-				QRegExp rx_files_read_all_files_except("files_read_all_files_except");
-				QRegExp rx_files_read_all_symlinks_except("files_read_all_symlinks_except");
-				QRegExp rx_files_relabel_all_files("files_relabel_all_files");
-				QRegExp rx_files_root_filetrans("files_root_filetrans");
-				QRegExp rx_files_spool_filetrans("files_spool_filetrans");
-				QRegExp rx_files_tmp_filetrans("files_tmp_filetrans");
-				QRegExp rx_files_usr_filetrans("files_usr_filetrans");
-				QRegExp rx_files_var_filetrans("files_var_filestrans");
-				QRegExp rx_files_var_lib_filetrans("files_var_lib_filetrans");
-				QRegExp rx_firstboot_run("firstboot_run");
-				QRegExp rx_fs_tmpfs_filetrans("fs_tmpfs_filetrans");
-				QRegExp rx_fstools_run("fstools_run");
-				QRegExp rx_hostname_run("hostname_run");
-				QRegExp rx_inetd_core_service_domain("inetd_core_services_domain");
-				QRegExp rx_init_daemon_domain("init_daemon_domain");
-				QRegExp rx_init_domain("init_domain");
-				QRegExp rx_init_run_daemon("init_run_daemon");
-				QRegExp rx_init_script_tmp_filetrans("init_script_tmp_filetrans");
-				QRegExp rx_init_system_domain("init_system_domain");
-				QRegExp rx_ipsec_run_setkey("ipsec_run_setkey");
-				QRegExp rx_iptables_run("iptables_run");
-				QRegExp rx_kernel_domtrans_to("kernel_domtrans_to");
-				QRegExp rx_kudzu_run("kudzu_run");
-				QRegExp rx_lib_filetrans_shared_lib("lib_filetrans_shared_lib");
-				QRegExp rx_libs_run_ldconfig("libs_run_ldconfig");
-				QRegExp rx_loadkeys_run("loadkeys_run");
-				QRegExp rx_logging_log_filetrans("logging_log_filetrans");
-				QRegExp rx_logging_run_auditctl("logging_run_auditctl");
-				QRegExp rx_logging_run_auditd("logging_run_auditd");
-				QRegExp rx_logrotate_run("logrotate_run");
-				QRegExp rx_lpd_run_checkpc("lpd_run_checkpc");
-				QRegExp rx_lvm_run("lvm_run");
-				QRegExp rx_modutils_run_depmod("modutils_run_depmod");
-				QRegExp rx_modutils_run_insmod("modutils_run_insmod");
-				QRegExp rx_modutils_run_update_mods("modutils_run_update_mods");
-				QRegExp rx_mount_run("mount_run");
-				QRegExp rx_mta_spool_filetrans("mta_spool_filetrans");
-				QRegExp rx_netlabel_run_mgmt("netlabel_run_mgmt");
-				QRegExp rx_netutils_run("netutils_run");
-				QRegExp rx_netutils_run_ping("netutils_run_ping");
-				QRegExp rx_netutils_run_ping_cond("netutils_run_ping_cond");
-				QRegExp rx_netutils_run_traceroute("netutils_run_traceroute");
-				QRegExp rx_netutils_run_traceroute_cond("netutils_run_traceroute_cond");
-				QRegExp rx_nscd_run("nscd_run");
-				QRegExp rx_oav_run_update("oav_run_update");
-				QRegExp rx_oddjob_system_entry("oddjob_system_entry");
-				QRegExp rx_pcmcia_run_cardctl("pcmcia_run_cardctl");
-				QRegExp rx_portage_main_domain("portage_main_domain");
-				QRegExp rx_portage_run("portage_run");
-				QRegExp rx_portage_run_gcc_config("portage_run_gcc_config");
-				QRegExp rx_portmap_run_helper("portmap_run_helper");
-				QRegExp rx_postfix_config_filetrans("postfix_config_filetrans");
-				QRegExp rx_postfix_run_map("postfix_run_map");
-				QRegExp rx_ppp_run("ppp_run");
-				QRegExp rx_ppp_run_cond("ppp_run_cond");
-				QRegExp rx_qmail_smtpd_service_domain("qmail_smtpd_service_domain");
-				QRegExp rx_quota_run("quota_run");
-				QRegExp rx_rpm_run("rpm_run");
-				QRegExp rx_samba_run_net("samba_run_net");
-				QRegExp rx_samba_run_winbind_helper("samba_run_winbind_helper");
-				QRegExp rx_seutil_init_script_run_runinit("seutil_init_script_run_runinit");
-				QRegExp rx_seutil_run_checkpolicy("seutil_run_checkpolicy");
-				QRegExp rx_seutil_run_loadpolicy("seutil_run_loadpolicy");
-				QRegExp rx_seutil_run_newrole("seutil_run_newrole");
-				QRegExp rx_seutil_run_runinit("seutil_run_runinit");
-				QRegExp rx_seutil_run_semanage("seutil_run_semanage");
-				QRegExp rx_seutil_run_setfiles("seutil_run_setfiles");
-				QRegExp rx_sysnet_dhcp_state_filetrans("sysnet_dhcp_state_filetrans");
-				QRegExp rx_sysnet_run_dhcpc("sysnet_run_dhcpc");
-				QRegExp rx_sysnet_run_ifconfig("sysnet_run_ifconfig");
-				QRegExp rx_tripwire_run_siggen("tripwire_run_siggen");
-				QRegExp rx_tripwire_run_tripwire("tripwire_run_tripwire");
-				QRegExp rx_tripwire_run_twadmin("tirpwire_run_twadmin");
-				QRegExp rx_tripwire_run_twprint("tripwire_run_twprint");
-				QRegExp rx_unconfined_domtrans_to("unconfined_domtrans_to");
-				QRegExp rx_unconfined_run("unconfined_run");
-				QRegExp rx_usbmodules_run("usbmodules_run");
-				QRegExp rx_userdom_generic_user_home_dir_filetrans_generic_user_home_content("userdom_generic_user_home_dir_filetrans_generic_user_home_content");
-				QRegExp rx_userdom_sysadm_home_dir_filetrans("userdom_sysadm_home_dir_filetrans");
-				QRegExp rx_usermanage_run_admin_passwd("usermanage_run_admin_passwd");
-				QRegExp rx_usermanage_run_chfn("usermanage_run_chfn");
-				QRegExp rx_usermanage_run_groupadd("usermanage_run_groupadd");
-				QRegExp rx_usermanage_run_passwd("usermanage_run_passwd");
-				QRegExp rx_usermanage_run_useradd("usermanage_run_useradd");
-				QRegExp rx_usernetctl_run("usernetctl_run");
-				QRegExp rx_vpn_run("vpn_run");
-				QRegExp rx_webalizer_run("webalizer_run");
-				QRegExp rx_yam_run("yam_run");
+QRegExp rx_interface4("\\$1");
+QRegExp rx_interface5("\\$2");
+QRegExp rx_interface6("\\$3");
+QRegExp rx_interface7("\\$4");
+
+QRegExp rx_amanda_run_recover("amanda_run_recover");
+QRegExp rx_amtu_run("amtu_run");
+QRegExp rx_apt_run("apt_run");
+QRegExp rx_backup_run("backup_run");
+QRegExp rx_bootloader_run("bootloader_run");
+QRegExp rx_certwatch_run("certwatch_run");
+QRegExp rx_consoletype_run("consoletype_run");
+QRegExp rx_ddcprobe_run("ddcprobe_run");
+QRegExp rx_dmidecode_run("dmidecode_run");
+QRegExp rx_dpkg_run("dpkg_run");
+QRegExp rx_firstboot_run("firstboot_run");
+QRegExp rx_kudzu_run("kudzu_run");
+QRegExp rx_logrotate_run("logrotate_run");
+QRegExp rx_netutils_run("netutils_run");
+QRegExp rx_netutils_run_ping("netutils_run_ping");
+QRegExp rx_netutils_run_ping_cond("netutils_run_ping_cond");
+QRegExp rx_netutils_run_traceroute("netutils_run_traceroute");
+QRegExp rx_netutils_run_traceroute_cond("netutils_run_traceroute_cond");
+QRegExp rx_portage_run("portage_run");
+QRegExp rx_portage_run_gcc_config("portage_run_gcc_config");
+QRegExp rx_quota_run("quota_run");
+QRegExp rx_rpm_run("rpm_run");
+QRegExp rx_tripwire_run_tripwire("tripwire_run_tripwire");
+QRegExp rx_tripwire_run_twadmin("tripwire_run_twadmin");
+QRegExp rx_tripwire_run_twprint("tripwire_run_twprint");
+QRegExp rx_tripwire_run_siggen("tripwire_run_siggen");
+QRegExp rx_usbmodules_run("usbmodules_run");
+QRegExp rx_usermanage_run_chfn("usermanage_run_chfn");
+QRegExp rx_usermanage_run_groupadd("usermanage_run_groupadd");
+QRegExp rx_usermanage_run_passwd("usermanage_run_passwd");
+QRegExp rx_usermanage_run_admin_passwd("usermanage_run_admin_passwd");
+QRegExp rx_usermanage_run_useradd("usermanage_run_useradd");
+QRegExp rx_vpn_run("vpn_run");
+QRegExp rx_ada_run("ada_run");
+QRegExp rx_ethereal_run_tethereal("ethereal_run_tethereal");
+QRegExp rx_evolution_dbus_chat("evolution_dbus_chat");
+QRegExp rx_evolution_alarm_dbus_chat("evolution_alarm_dbus_chat");
+QRegExp rx_loadkeys_run("loadkeys_run");
+QRegExp rx_usernetctl_run("usernetctl_run");
+QRegExp rx_webalizer_run("webalizer_run");
+QRegExp rx_wine_run("wine_run");
+QRegExp rx_yam_run("yam_run");
+QRegExp rx_aide_run("aide_run");
+QRegExp rx_amavis_spool_filetrans("amavis_spool_filetrans");
+QRegExp rx_apache_run_helper("apache_run_helper");
+QRegExp rx_apache_run_all_scripts("apache_run_all_scripts");
+QRegExp rx_apache_cgi_domain("apache_cgi_domain");
+QRegExp rx_bind_run_ndc("bind_run_ndc");
+QRegExp rx_bluetooth_run_helper("bluetooth_run_helper");
+QRegExp rx_clockspeed_run_cli("clockspeed_run_cli");
+QRegExp rx_cron_system_entry("cron_system_entry");
+QRegExp rx_dcc_run_cdcc("dcc_run_cdcc");
+QRegExp rx_dcc_run_client("dcc_run_client");
+QRegExp rx_dcc_run_dbclean("dcc_run_dbclean");
+QRegExp rx_inetd_core_service_domain("inetd_core_service_domain");
+QRegExp rx_inetd_tcp_service_domain("inetd_tcp_service_domain");
+QRegExp rx_inetd_udp_service_domain("inetd_udp_service_domain");
+QRegExp rx_inetd_service_domain("inetd_service_domain");
+QRegExp rx_lpd_run_checkpc("lpd_run_checkpc");
+QRegExp rx_mta_mailserver("mta_mailserver");
+QRegExp rx_mta_sendmail_domtrans("mta_sendmail_domtrans");
+QRegExp rx_mta_spool_filetrans("mta_spool_filetrans");
+QRegExp rx_nscd_run("nscd_run");
+QRegExp rx_oav_run_update("oav_run_update");
+QRegExp rx_openvpn_run("openvpn_run");
+QRegExp rx_portmap_run_helper("portmap_run_helper");
+QRegExp rx_postfix_config_filetrans("postfix_config_filetrans");
+QRegExp rx_postfix_run_map("postfix_run_map");
+QRegExp rx_ppp_run_cond("ppp_run_cond");
+QRegExp rx_ppp_run("ppp_run");
+QRegExp rx_qmail_smtpd_service_domain("qmail_smtpd_service_domain");
+QRegExp rx_rsync_entry_spec_domtrans("rsync_entry_spec_domtrans");
+QRegExp rx_rsync_entry_domtrans("rsync_entry_domtrans");
+QRegExp rx_samba_run_net("samba_run_net");
+QRegExp rx_samba_run_winbind_helper("samba_run_winbind_helper");
+QRegExp rx_tcpd_wrapped_domain("tcpd_wrapped_domain");
+QRegExp rx_ucspitcp_service_domain("ucspitcp_service_domain");
+QRegExp rx_xserver_xsession_spec_domtrans("xserver_xsession_spec_domtrans");
+QRegExp rx_application_domain("application_domain");
+QRegExp rx_auth_domtrans_login_program("auth_domtrans_login_program");
+QRegExp rx_auth_ranged_domtrans_login_program("auth_ranged_domtrans_login_program");
+QRegExp rx_auth_run_pam("auth_run_pam");
+QRegExp rx_auth_read_all_dirs_except_shadow("auth_read_all_dirs_except_shadow");
+QRegExp rx_auth_read_all_files_except_shadow("auth_read_all_files_except_shadow");
+QRegExp rx_auth_read_all_symlinks_except_shadow("auth_read_all_symlinks_except_shadow");
+QRegExp rx_auth_relabel_all_files_except_shadow("auth_relabel_all_files_except_shadow");
+QRegExp rx_auth_manage_all_files_except_shadow("auth_manage_all_files_except_shadow");
+QRegExp rx_auth_run_utempter("auth_run_utempter");
+QRegExp rx_clock_run("clock_run");
+QRegExp rx_daemontools_service_domain("daemontools_service_domain");
+QRegExp rx_fstools_run("fstools_run");
+QRegExp rx_hostname_run("hostname_run");
+QRegExp rx_init_domain("init_domain");
+QRegExp rx_init_ranged_domain("init_ranged_domain");
+QRegExp rx_init_daemon_domain("init_daemon_domain");
+QRegExp rx_init_ranged_daemon_domain("init_ranged_daemon_domain");
+QRegExp rx_init_system_domain("init_system_domain");
+QRegExp rx_init_ranged_system_domain("init_ranged_system_domain");
+QRegExp rx_init_script_file_domtrans("init_script_file_domtrans");
+QRegExp rx_init_run_daemon("init_run_daemon");
+QRegExp rx_init_script_tmp_filetrans("init_script_tmp_filetrans");
+QRegExp rx_ipsec_run_setkey("ipsec_run_setkey");
+QRegExp rx_iptables_run("iptables_run");
+QRegExp rx_libs_run_ldconfig("libs_run_ldconfig");
+QRegExp rx_lib_filetrans_shared_lib("lib_filetrans_shared_lib");
+QRegExp rx_files_lib_filetrans_shared_lib("files_lib_filetrans_shared_lib");
+QRegExp rx_logging_run_auditctl("logging_run_auditctl");
+QRegExp rx_logging_run_auditd("logging_run_auditd");
+QRegExp rx_logging_log_filetrans("logging_log_filetrans");
+QRegExp rx_lvm_run("lvm_run");
+QRegExp rx_modutils_run_insmod("modutils_run_insmod");
+QRegExp rx_modutils_run_depmod("modutils_run_depmod");
+QRegExp rx_modutils_run_update_mods("modutils_run_update_mods");
+QRegExp rx_mount_run("mount_run");
+QRegExp rx_netlabel_run_mgmt("netlabel_run_mgmt");
+QRegExp rx_pcmcia_run_cardctl("pcmcia_run_cardctl");
+QRegExp rx_seutil_run_checkpolicy("seutil_run_checkpolicy");
+QRegExp rx_seutil_run_loadpolicy("seutil_run_loadpolicy");
+QRegExp rx_seutil_run_newrole("seutil_run_newrole");
+QRegExp rx_seutil_run_restorecon("seutil_run_restorecon");
+QRegExp rx_seutil_run_runinit("seutil_run_runinit");
+QRegExp rx_seutil_init_script_run_runinit("seutil_init_script_run_runinit");
+QRegExp rx_seutil_run_setfiles("seutil_run_setfiles");
+QRegExp rx_seutil_run_semanage("seutil_run_semanage");
+QRegExp rx_sysnet_run_dhcpc("sysnet_run_dhcpc");
+QRegExp rx_sysnet_run_ifconfig("sysnet_run_ifconfig");
+QRegExp rx_sysnet_dhcp_state_filetrans("sysnet_dhcp_state_filetrans");
+QRegExp rx_unconfined_run("unconfined_run");
+QRegExp rx_userdom_sysadm_home_dir_filetrans("userdom_sysadm_home_dir_filetrans");
+QRegExp rx_userdom_generic_user_home_dir_filetrans_generic_user_home_content("userdom_generic_user_home_dir_filetrans_generic_user_home_content");
+
 
 				cumma = ",";
 				
@@ -273,6 +279,8 @@ void SelpawAdjust::adjust_selpaw()
 
 					if(
 						(line_analized.find( rx_interface5, 0) != -1)||
+						
+/*						
 						(line_analized.find( rx_aide_run, 0) != -1)||
 						(line_analized.find( rx_amanda_run_recover, 0) != -1)||
 						(line_analized.find( rx_amavis_spool_filetrans, 0) != -1)||
@@ -398,6 +406,137 @@ void SelpawAdjust::adjust_selpaw()
 						(line_analized.find( rx_vpn_run, 0) != -1)||
 						(line_analized.find( rx_webalizer_run, 0) != -1)||
 						(line_analized.find( rx_yam_run, 0) != -1)
+*/
+(line_analized.find( rx_amanda_run_recover, 0) != -1)||
+(line_analized.find( rx_amtu_run, 0) != -1)||
+(line_analized.find( rx_apt_run, 0) != -1)||
+(line_analized.find( rx_backup_run, 0) != -1)||
+(line_analized.find( rx_bootloader_run, 0) != -1)||
+(line_analized.find( rx_certwatch_run, 0) != -1)||
+(line_analized.find( rx_consoletype_run, 0) != -1)||
+(line_analized.find( rx_ddcprobe_run, 0) != -1)||
+(line_analized.find( rx_dmidecode_run, 0) != -1)||
+(line_analized.find( rx_dpkg_run, 0) != -1)||
+(line_analized.find( rx_firstboot_run, 0) != -1)||
+(line_analized.find( rx_kudzu_run, 0) != -1)||
+(line_analized.find( rx_logrotate_run, 0) != -1)||
+(line_analized.find( rx_netutils_run, 0) != -1)||
+(line_analized.find( rx_netutils_run_ping, 0) != -1)||
+(line_analized.find( rx_netutils_run_ping_cond, 0) != -1)||
+(line_analized.find( rx_netutils_run_traceroute, 0) != -1)||
+(line_analized.find( rx_netutils_run_traceroute_cond, 0) != -1)||
+(line_analized.find( rx_portage_run, 0) != -1)||
+(line_analized.find( rx_portage_run_gcc_config, 0) != -1)||
+(line_analized.find( rx_quota_run, 0) != -1)||
+(line_analized.find( rx_rpm_run, 0) != -1)||
+(line_analized.find( rx_tripwire_run_tripwire, 0) != -1)||
+(line_analized.find( rx_tripwire_run_twadmin, 0) != -1)||
+(line_analized.find( rx_tripwire_run_twprint, 0) != -1)||
+(line_analized.find( rx_tripwire_run_siggen, 0) != -1)||
+(line_analized.find( rx_usbmodules_run, 0) != -1)||
+(line_analized.find( rx_usermanage_run_chfn, 0) != -1)||
+(line_analized.find( rx_usermanage_run_groupadd, 0) != -1)||
+(line_analized.find( rx_usermanage_run_passwd, 0) != -1)||
+(line_analized.find( rx_usermanage_run_admin_passwd, 0) != -1)||
+(line_analized.find( rx_usermanage_run_useradd, 0) != -1)||
+(line_analized.find( rx_vpn_run, 0) != -1)||
+(line_analized.find( rx_ada_run, 0) != -1)||
+(line_analized.find( rx_ethereal_run_tethereal, 0) != -1)||
+(line_analized.find( rx_evolution_dbus_chat, 0) != -1)||
+(line_analized.find( rx_evolution_alarm_dbus_chat, 0) != -1)||
+(line_analized.find( rx_loadkeys_run, 0) != -1)||
+(line_analized.find( rx_usernetctl_run, 0) != -1)||
+(line_analized.find( rx_webalizer_run, 0) != -1)||
+(line_analized.find( rx_wine_run, 0) != -1)||
+(line_analized.find( rx_yam_run, 0) != -1)||
+(line_analized.find( rx_aide_run, 0) != -1)||
+(line_analized.find( rx_amavis_spool_filetrans, 0) != -1)||
+(line_analized.find( rx_apache_run_helper, 0) != -1)||
+(line_analized.find( rx_apache_run_all_scripts, 0) != -1)||
+(line_analized.find( rx_apache_cgi_domain, 0) != -1)||
+(line_analized.find( rx_bind_run_ndc, 0) != -1)||
+(line_analized.find( rx_bluetooth_run_helper, 0) != -1)||
+(line_analized.find( rx_clockspeed_run_cli, 0) != -1)||
+(line_analized.find( rx_cron_system_entry, 0) != -1)||
+(line_analized.find( rx_dcc_run_cdcc, 0) != -1)||
+(line_analized.find( rx_dcc_run_client, 0) != -1)||
+(line_analized.find( rx_dcc_run_dbclean, 0) != -1)||
+(line_analized.find( rx_inetd_core_service_domain, 0) != -1)||
+(line_analized.find( rx_inetd_tcp_service_domain, 0) != -1)||
+(line_analized.find( rx_inetd_udp_service_domain, 0) != -1)||
+(line_analized.find( rx_inetd_service_domain, 0) != -1)||
+(line_analized.find( rx_lpd_run_checkpc, 0) != -1)||
+(line_analized.find( rx_mta_mailserver, 0) != -1)||
+(line_analized.find( rx_mta_sendmail_domtrans, 0) != -1)||
+(line_analized.find( rx_mta_spool_filetrans, 0) != -1)||
+(line_analized.find( rx_nscd_run, 0) != -1)||
+(line_analized.find( rx_oav_run_update, 0) != -1)||
+(line_analized.find( rx_openvpn_run, 0) != -1)||
+(line_analized.find( rx_portmap_run_helper, 0) != -1)||
+(line_analized.find( rx_postfix_config_filetrans, 0) != -1)||
+(line_analized.find( rx_postfix_run_map, 0) != -1)||
+(line_analized.find( rx_ppp_run_cond, 0) != -1)||
+(line_analized.find( rx_ppp_run, 0) != -1)||
+(line_analized.find( rx_qmail_smtpd_service_domain, 0) != -1)||
+(line_analized.find( rx_rsync_entry_spec_domtrans, 0) != -1)||
+(line_analized.find( rx_rsync_entry_domtrans, 0) != -1)||
+(line_analized.find( rx_samba_run_net, 0) != -1)||
+(line_analized.find( rx_samba_run_winbind_helper, 0) != -1)||
+(line_analized.find( rx_tcpd_wrapped_domain, 0) != -1)||
+(line_analized.find( rx_ucspitcp_service_domain, 0) != -1)||
+(line_analized.find( rx_xserver_xsession_spec_domtrans, 0) != -1)||
+(line_analized.find( rx_application_domain, 0) != -1)||
+(line_analized.find( rx_auth_domtrans_login_program, 0) != -1)||
+(line_analized.find( rx_auth_ranged_domtrans_login_program, 0) != -1)||
+(line_analized.find( rx_auth_run_pam, 0) != -1)||
+(line_analized.find( rx_auth_read_all_dirs_except_shadow, 0) != -1)||
+(line_analized.find( rx_auth_read_all_files_except_shadow, 0) != -1)||
+(line_analized.find( rx_auth_read_all_symlinks_except_shadow, 0) != -1)||
+(line_analized.find( rx_auth_relabel_all_files_except_shadow, 0) != -1)||
+(line_analized.find( rx_auth_manage_all_files_except_shadow, 0) != -1)||
+(line_analized.find( rx_auth_run_utempter, 0) != -1)||
+(line_analized.find( rx_clock_run, 0) != -1)||
+(line_analized.find( rx_daemontools_service_domain, 0) != -1)||
+(line_analized.find( rx_fstools_run, 0) != -1)||
+(line_analized.find( rx_hostname_run, 0) != -1)||
+(line_analized.find( rx_init_domain, 0) != -1)||
+(line_analized.find( rx_init_ranged_domain, 0) != -1)||
+(line_analized.find( rx_init_daemon_domain, 0) != -1)||
+(line_analized.find( rx_init_ranged_daemon_domain, 0) != -1)||
+(line_analized.find( rx_init_system_domain, 0) != -1)||
+(line_analized.find( rx_init_ranged_system_domain, 0) != -1)||
+(line_analized.find( rx_init_script_file_domtrans, 0) != -1)||
+(line_analized.find( rx_init_run_daemon, 0) != -1)||
+(line_analized.find( rx_init_script_tmp_filetrans, 0) != -1)||
+(line_analized.find( rx_ipsec_run_setkey, 0) != -1)||
+(line_analized.find( rx_iptables_run, 0) != -1)||
+(line_analized.find( rx_libs_run_ldconfig, 0) != -1)||
+(line_analized.find( rx_lib_filetrans_shared_lib, 0) != -1)||
+(line_analized.find( rx_files_lib_filetrans_shared_lib, 0) != -1)||
+(line_analized.find( rx_logging_run_auditctl, 0) != -1)||
+(line_analized.find( rx_logging_run_auditd, 0) != -1)||
+(line_analized.find( rx_logging_log_filetrans, 0) != -1)||
+(line_analized.find( rx_lvm_run, 0) != -1)||
+(line_analized.find( rx_modutils_run_insmod, 0) != -1)||
+(line_analized.find( rx_modutils_run_depmod, 0) != -1)||
+(line_analized.find( rx_modutils_run_update_mods, 0) != -1)||
+(line_analized.find( rx_mount_run, 0) != -1)||
+(line_analized.find( rx_netlabel_run_mgmt, 0) != -1)||
+(line_analized.find( rx_pcmcia_run_cardctl, 0) != -1)||
+(line_analized.find( rx_seutil_run_checkpolicy, 0) != -1)||
+(line_analized.find( rx_seutil_run_loadpolicy, 0) != -1)||
+(line_analized.find( rx_seutil_run_newrole, 0) != -1)||
+(line_analized.find( rx_seutil_run_restorecon, 0) != -1)||
+(line_analized.find( rx_seutil_run_runinit, 0) != -1)||
+(line_analized.find( rx_seutil_init_script_run_runinit, 0) != -1)||
+(line_analized.find( rx_seutil_run_setfiles, 0) != -1)||
+(line_analized.find( rx_seutil_run_semanage, 0) != -1)||
+(line_analized.find( rx_sysnet_run_dhcpc, 0) != -1)||
+(line_analized.find( rx_sysnet_run_ifconfig, 0) != -1)||
+(line_analized.find( rx_sysnet_dhcp_state_filetrans, 0) != -1)||
+(line_analized.find( rx_unconfined_run, 0) != -1)||
+(line_analized.find( rx_userdom_sysadm_home_dir_filetrans, 0) != -1)||
+(line_analized.find( rx_userdom_generic_user_home_dir_filetrans_generic_user_home_content, 0) != -1)
 
 
 
