@@ -1,8 +1,7 @@
 /*
- * segatex_editor SELinux tool.
+ * segatex SELinux tool.
  *
  * Copyright (C) 2007 Shintaro Fujiwara 
- * shintaro.fujiwara@gmai.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,32 +25,31 @@
 
 class SelpawAdjust: public Selpaw
 {
-    Q_OBJECT
+	Q_OBJECT
 public:
-    SelpawAdjust();
-    SelpawAdjust(QSplitter*&);
-    ~SelpawAdjust();
-    
+	SelpawAdjust();
+	SelpawAdjust(QSplitter*&);
+
 public slots:
-    void adjust_selpaw_ready();
-    void adjust_selpaw();
-    void refine_selpaw();
-    void refine_selpaw_types();
-    void refine_selpaw_types_final();
-    void sort_selpaw_types();
-    void sort_selpaw_summary();
+	void adjust_selpaw_ready();
+	void adjust_selpaw();
+	void refine_selpaw();
+	void refine_selpaw_types();
+	void refine_selpaw_types_final();
+	void sort_selpaw_types();
+	void sort_selpaw_summary();
 
 signals:
 
 protected:
 
 private:
-    QStringList lines_interface_name;
-    QStringList lines;
-    QString cumma;
-    QString interface_name_this_to_be_replaced;
-    QString file_interface_gen_require;
-    QString line_analized2;
+	QStringList lines_interface_name;
+	QStringList lines;
+	QString cumma;
+	QString interface_name_this_to_be_replaced;
+	QString file_interface_gen_require;
+	QString line_analized2;
 };
 
 #endif
